@@ -1,16 +1,16 @@
+from __future__ import annotations
+
 from media_platform.metadata.file_metadata import FileMetadata, MediaType
 from media_platform.metadata.font.font_basic import FontBasic
 from media_platform.service.file_descriptor import FileDescriptor
 
 
 class FontFileMetadata(FileMetadata):
-    def __init__(self, file_descriptor, basic=None):
-        # type: (FileDescriptor, FontBasic) -> None
-        super(FontFileMetadata, self).__init__(MediaType.font, file_descriptor, basic)
+    def __init__(self, file_descriptor: FileDescriptor, basic: FontBasic = None):
+        super().__init__(MediaType.font, file_descriptor, basic)
 
     @classmethod
-    def deserialize(cls, data):
-        # type: (dict) -> FontFileMetadata
+    def deserialize(cls, data: dict) -> FontFileMetadata:
         if data['mediaType'] != MediaType.font:
             raise ValueError('not font metadata')
 
